pub enum InterpolantColor {
A,
B,
AB,
}Expand description
Color of a proof node in the interpolation procedure
Variants
A
Node depends only on A premises
B
Node depends only on B premises
AB
Node depends on both A and B premises (mixed)