Lemma pattern extraction from proofs.
This module extracts reusable patterns from successful proofs to enable proof-based learning and improve solver heuristics.
Structs
- Lemma
Pattern - A pattern extracted from a lemma or proof fragment.
- Pattern
Extractor - Pattern extractor for analyzing proofs.
Enums
- Pattern
Structure - The structure of a pattern (simplified representation).